@@ -39,17 +39,17 @@
   cdm <- omopgenerics::cdmReference(x)
   # initial checks
   personVariable <- checkX(x)
-  checkmate::assertCharacter(tableName, len = 1, any.missing = FALSE)
-  assertCharacter(tableName)
+  omopgenerics::assertCharacter(tableName, length = 1, na = FALSE)
+  omopgenerics::assertCharacter(tableName)
   checkCdm(cdm, tableName)
   personVariableTable <- checkX(cdm[[tableName]])
   extraValue <- checkValue(value, cdm[[tableName]], tableName)
   filterTbl <- checkFilter(filterVariable, filterId, idName, cdm[[tableName]])
-  window <- checkWindow(window)
+  window <- omopgenerics::validateWindowArgument(window)
   checkVariableInX(indexDate, x)
   checkVariableInX(targetStartDate, cdm[[tableName]], FALSE, "targetStartDate")
   checkVariableInX(targetEndDate, cdm[[tableName]], TRUE, "targetEndDate")
-  checkmate::assertChoice(order, c("first", "last"))
+  omopgenerics::assertChoice(order, choices = c("first", "last"))
   checkVariableInX(censorDate, x, TRUE, "censorDate")
 
   if (!is.null(censorDate)) {
@@ -308,7 +308,12 @@
         values_fill = 0
       ) %>%
       dplyr::rename(!!indexDate := "index_date") %>%
-      dplyr::rename_all(tolower)
+      dplyr::rename_all(tolower) |>
+      dplyr::compute(
+        name = omopgenerics::uniqueTableName(tablePrefix),
+        temporary = FALSE,
+        overwrite = TRUE
+      )
 
     newColCountFlag <- colnames(resultCountFlagPivot)
     newColCountFlag <- newColCountFlag[newColCountFlag %in% newCols$colnam]
@@ -317,7 +322,14 @@
       dplyr::left_join(
         resultCountFlagPivot,
         by = c(personVariable, indexDate)
-      ) %>%
+      ) |>
+      dplyr::compute(
+        name = omopgenerics::uniqueTableName(tablePrefix),
+        temporary = FALSE,
+        overwrite = TRUE
+      )
+
+    x <- x %>%
       dplyr::mutate(dplyr::across(
         dplyr::all_of(newColCountFlag), ~ dplyr::if_else(is.na(.x), 0, .x)
       )) |>
