@@ -60,7 +60,7 @@ mockPatientProfiles <- function(con = NULL,
 
   # Put ... into a list
   tables <- list(...)
-  assertList(tables, named = TRUE, class = "data.frame")
+  omopgenerics::assertList(tables, named = TRUE, class = "data.frame")
 
   # get persons
   if (length(tables) == 0) {
@@ -83,8 +83,8 @@ mockPatientProfiles <- function(con = NULL,
   if (!"person" %in% names(tables)) {
     tables[["person"]] <- dplyr::tibble(
       "person_id" = persons,
-      "gender_concept_id" = sample(c(8532, 8507), n, TRUE),
-      "year_of_birth" = 1900L + sample.int(120, n, TRUE),
+      "gender_concept_id" = as.integer(sample(c(8532, 8507), n, TRUE)),
+      "year_of_birth" = 1900L + sample.int(80, n, TRUE),
       "race_concept_id" = 0L,
       "ethnicity_concept_id" = 0L
     )
@@ -136,7 +136,7 @@ mockPatientProfiles <- function(con = NULL,
           is.na(.data$observation_period_start_date),
           as.Date(
             x = paste0(
-              .data$year_of_birth + sample.int(120, n, TRUE), "-", sample(1:12, n, TRUE), "-",
+              .data$year_of_birth + sample.int(34, n, TRUE), "-", sample(1:12, n, TRUE), "-",
               sample(1:28, n, TRUE)
             ),
             format = "%Y-%m-%d"
@@ -145,7 +145,7 @@ mockPatientProfiles <- function(con = NULL,
         ),
         "observation_period_end_date" = dplyr::if_else(
           is.na(.data$observation_period_end_date),
-          .data$observation_period_start_date + sample.int(4e4, n, TRUE),
+          .data$observation_period_start_date + sample.int(1e4, n, TRUE),
           .data$observation_period_end_date
         ),
         "period_type_concept_id" = 0L,
@@ -282,7 +282,9 @@ mockPatientProfiles <- function(con = NULL,
       dplyr::ungroup() |>
       addDate(c("cohort_start_date", "cohort_end_date")) |>
       dplyr::mutate("cohort_definition_id" = sample.int(3, n, T)) |>
-      dplyr::rename("subject_id" = "person_id")
+      dplyr::rename("subject_id" = "person_id") |>
+      dplyr::select("cohort_definition_id", "subject_id",
+                    "cohort_start_date", "cohort_end_date")
   }
 
   # create cohort2
@@ -301,7 +303,9 @@ mockPatientProfiles <- function(con = NULL,
       dplyr::ungroup() |>
       addDate(c("cohort_start_date", "cohort_end_date")) |>
       dplyr::mutate("cohort_definition_id" = sample.int(3, n, T)) |>
-      dplyr::rename("subject_id" = "person_id")
+      dplyr::rename("subject_id" = "person_id") |>
+      dplyr::select("cohort_definition_id", "subject_id",
+                    "cohort_start_date", "cohort_end_date")
   }
 
   # into database
@@ -374,7 +378,7 @@ addDate <- function(x, cols) {
 #'
 mockDisconnect <- function(cdm) {
   cdm <- omopgenerics::dropTable(cdm = cdm, name = dplyr::everything())
-  if ("db_cdm" %in% class(omopgenerics::cdmSource(cdm = cdm))) {
+  if ("db_cdm" %in% class(omopgenerics::cdmSource(cdm))) {
     con <- CDMConnector::cdmCon(cdm = cdm)
     DBI::dbDisconnect(conn = con, shutdown = TRUE)
   }
